Skip to contents

Generate Validation Benchmark Report

Usage

generate_validation_report(
  benchmark_results,
  output_file = "Validation_report.html",
  template = NULL
)

Arguments

benchmark_results

A list containing `metrics` (data.frame), `aligned_data` (data.frame), and `plots` (list of ggplot objects) returned by the validation pipeline.

output_file

The path where the compiled report should be saved (e.g., "validation_report.html").

template

The path to the Quarto template. Defaults to the one provided in the package `inst/reports/Validation_report.qmd`.

Author

PEcAn Project