Skip to contents

Load and standardize arbitrary tabular data using a YAML mapping configuration

Usage

load_and_map_data(data.path, mapping.path)

Arguments

data.path

character, file path to the tabular data (e.g. .csv)

mapping.path

character, file path to the YAML mapping configuration

Value

A standardized data frame with column names mapped to PEcAn standard vocabulary