Prediction Interval Coverage
Usage
metric_Coverage(dat, ...)
Arguments
- dat
dataframe with columns `model_q05` and `model_q95` (or `model_q025` and `model_q975`)
- ...
ignored
Value
A numeric value representing the fraction of observations that fall within the prediction interval.
Details
Measures the fraction of observations that fall within the model's
stated prediction interval (defaults to 90